@@ -4,7 +4,7 @@
 
 #ifndef KERNEL_SGEMM_COL_NN_B0_MX032_NX032_KX16_SRC_H
 #define KERNEL_SGEMM_COL_NN_B0_MX032_NX032_KX16_SRC_H
-#pragma message("AutoGemm's sgemm_Col_NN_B0_MX032_NX032_KX16_src overriden by user.")
+// #pragma message("AutoGemm's sgemm_Col_NN_B0_MX032_NX032_KX16_src overriden by user.")
 
 #ifndef STRINGIFY
 #define STRINGIFY(S) STRINGIFY2(S)
