@@ -4,7 +4,7 @@
 
 #ifndef KERNEL_SGEMM_COL_NT_B1_MX032_NX032_KX16_BRANCH_SRC_H
 #define KERNEL_SGEMM_COL_NT_B1_MX032_NX032_KX16_BRANCH_SRC_H
-#pragma message("AutoGemm's sgemm_Col_NT_B1_MX032_NX032_KX16_BRANCH_src (if exists) overriden by user.")
+// #pragma message("AutoGemm's sgemm_Col_NT_B1_MX032_NX032_KX16_BRANCH_src (if exists) overriden by user.")
 
 #ifndef STRINGIFY
 #define STRINGIFY(S) STRINGIFY2(S)
@@ -57,41 +57,41 @@ __kernel void sgemm_Col_NT_B1_MX032_NX032_KX16_BRANCH (
     float rC[2][2]  = { {(float)0} };
     float rA[1][2];
     float rB[1][2];
-    
-    
+
+
     A += offsetA;
     B += offsetB;
     C+=offsetC;
-    
+
     __local float lA[528];//16*32+16
     __local float lB[528];
-    
+
     uint gidx = get_group_id(0);
     uint gidy = get_group_id(1);
     uint idx = get_local_id(0);
     uint idy = get_local_id(1);
-    
+
 	int CurrentOffSetA = gidx*32+ idx;
 	int CurrentOffSetB = gidy*32+ idx;
-    
+
     A +=  gidx*32+ idx + idy*lda;
     B +=  gidy*32+ idx + idy*ldb;
-    
-   
+
+
     uint block_k = K >> 4;
-    do 
+    do
 	{
         __local float* plA = lA + idy*33+idx;
         __local float* plB = lB + idy*33+idx;
         barrier(CLK_LOCAL_MEM_FENCE);
-		
+
         plB[0]  = CurrentOffSetB>=N?0.0:B[0];
         plB[16] = CurrentOffSetB+16>=N?0.0:B[16];
-	   
+
 	    plA[0]  = CurrentOffSetA>=M?0.0:A[0];
         plA[16] = CurrentOffSetA+16>=M?0.0:A[16];
 
-        
+
         barrier(CLK_LOCAL_MEM_FENCE);
         uint offA = idx;
         uint offB = idy;
@@ -126,23 +126,35 @@ __kernel void sgemm_Col_NT_B1_MX032_NX032_KX16_BRANCH (
       return;
 
     C+=offset_x+offset_y*ldc;
-    
+
 	int i = 0;
-    do 
-	{
-	  C[0     ] = mad(alpha, rC[i][0], beta*C[0]);
-	  if(offset_y+16<N)
-        C[16*ldc] = mad(alpha, rC[i][1], beta*C[16*ldc]);
-      
-	  C+=16;
-	  offset_x+=16;
-	  if(offset_x>=M )
-        return;
+    if (beta !=0 ) {
+      do
+      {
+        C[0     ] = mad(alpha, rC[i][0], beta*C[0]);
+        if(offset_y+16<N)
+          C[16*ldc] = mad(alpha, rC[i][1], beta*C[16*ldc]);
 
-	    
-	}
-    while (++i < 2);
+        C+=16;
+        offset_x+=16;
+        if(offset_x>=M )
+          return;
+      }
+      while (++i < 2);
+    } else {
+      do
+      {
+        C[0     ] = alpha * rC[i][0];
+        if(offset_y+16<N)
+          C[16*ldc] = alpha * rC[i][1];
 
+        C+=16;
+        offset_x+=16;
+        if(offset_x>=M )
+          return;
+      }
+      while (++i < 2);
+    }
 }
 );
 #endif
