@@ -28,7 +28,7 @@
 #include <sys/stat.h>
 
 #include <devinfo.h>
-
+#include <stdlib.h>
 
 
 
@@ -54,7 +54,7 @@ extern "C"
 
 #include <string.h>
 
-char * sep()
+static char * sep()
 {
 #ifdef __WIN32
     return (char*)"\\";
@@ -195,7 +195,7 @@ enum BinaryRepresentation
     UNKNOWN
 };
 
-enum BinaryRepresentation getStorageMode(char * data)
+static enum BinaryRepresentation getStorageMode(char * data)
 {
     if (data[0] == 'C' && 
         data[1] == 'L' && 
