@@ -926,12 +926,12 @@ assignKargs(KernelArg *args, const void *params, const void *extra)
         initSizeKarg(&args[i++], blasArgs->offCY);
     }
     if (!(kflags & KEXTRA_INCX_ONE)) {
-        inc = blasArgs->ldb.vector;
+        inc = blasArgs->ldb.Vector;
         INIT_KARG(&args[i], inc);
         i++;
     }
     if (!(kflags & KEXTRA_INCY_ONE)) {
-        inc = blasArgs->ldc.vector;
+        inc = blasArgs->ldc.Vector;
         INIT_KARG(&args[i], inc);
         i++;
     }
@@ -949,13 +949,13 @@ fixupArgs(void *args, SubproblemDim *subdims, void *extra)
     (void)subdims;
 
     if (kargs->offsetN) {
-        if (kargs->ldc.vector < 0) {
+        if (kargs->ldc.Vector < 0) {
             // K store the original height of the matrix A
             kargs->offCY += (kargs->K - kargs->offsetN) *
-                            abs(kargs->ldc.vector);
+                            abs(kargs->ldc.Vector);
         }
         else {
-            kargs->offCY += kargs->offsetN * kargs->ldc.vector;
+            kargs->offCY += kargs->offsetN * kargs->ldc.Vector;
         }
     }
 }
