@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <clBLAS.h>
+#include "mutex.h"
 #include "AutoGemmIncludes/AutoGemmKernelSelection.h"
 #include "GemmSpecialCases.h"
 
@@ -27,6 +28,12 @@
 // #include <functor_selector.h>
 #include "xgemm.h"
 
+#ifdef _WIN32
+//#include <thread>
+#else
+#include <pthread.h>
+#endif
+
 /******************************************************************************
  * Row major -> column major
  *****************************************************************************/
@@ -61,6 +68,9 @@ static void force_gemm_column_major(
     printf("OpenCL error %i on line %u of %s\n", RET, __LINE__, __FILE__); \
     assert(false); \
   }
+#define returnIfErr(err) \
+	if (err != CL_SUCCESS)\
+		return static_cast<clblasStatus>(err);
 
 const static unsigned int numGemmKernelArgs = 14;
 void *gemmKernelArgs[numGemmKernelArgs];
@@ -117,12 +127,38 @@ static char *getKernelName(cl_kernel clKernel)
   return kernelName;
 }
 
+typedef struct kernel_map_key_ {
+  cl_context context; // address of context
+  cl_device_id device; // address of device
+  const char *kernelSource; // address of kernel source
+} kernel_map_key;
+
+bool operator<(const kernel_map_key & l, const kernel_map_key & r) {
+  if (l.context < r.context) {
+    return true;
+  } else if (r.context < l.context) {
+    return false;
+  }
+  if (l.device < r.device) {
+    return true;
+  } else if (r.device < l.device) {
+    return false;
+  }
+  if (l.kernelSource < r.kernelSource) {
+    return true;
+  } else if (r.kernelSource < l.kernelSource) {
+    return false;
+  }
+  return false;
+}
+
+
 /******************************************************************************
  * Make Gemm Kernel
  *****************************************************************************/
 //FIXME: This function should be returning an error.
 void makeGemmKernel(
-  cl_kernel *clKernel,
+  cl_kernel *clKernel, // ignored as input; returns as output only
   cl_command_queue clQueue,
   const char *kernelSource,
   const char *sourceBuildOptions,
@@ -130,9 +166,15 @@ void makeGemmKernel(
   size_t *kernelBinarySize,
   const char *binaryBuildOptions)
 {
-  //TODO: This will need to be converted to thread local when making clBLAS thread safe
-  typedef std::map<std::string, cl_kernel> kernel_map_t;
-  static kernel_map_t kernel_map;
+  typedef std::map<kernel_map_key, cl_kernel> kernel_map_t;
+  #if defined( _WIN32 )
+  __declspec( thread ) static kernel_map_t *kernel_map = 0;
+#else
+  static __thread kernel_map_t *kernel_map = 0;
+#endif
+  if (!kernel_map) {
+    kernel_map = new kernel_map_t();
+  }
 
   cl_context clContext;
   cl_device_id clDevice;
@@ -143,33 +185,20 @@ void makeGemmKernel(
   err = clGetCommandQueueInfo( clQueue, CL_QUEUE_DEVICE, sizeof(clDevice), &clDevice, NULL);
   CL_CHECK(err)
 
-  std::stringstream ss;
-  ss << clDevice << "_" << clContext;
-  std::string prefix = ss.str();
-
-  if (*clKernel) {
-    char *kernelName = getKernelName(*clKernel);
-    // kernel has already been built, return
-#ifdef AUTOGEMM_PRINT_DEBUG
-    printf("makeGemmKernel: \"%s\" already built; returning.\n", kernelName);
-#endif
-
-    // Check if kernel exists for this device
-    std::string key = prefix + "_" + kernelName;
-    kernel_map_t::iterator idx = kernel_map.find(key);
-
-
-    // If kernel not found for this device, set to NULL
-    if (idx == kernel_map.end()) {
-        *clKernel = NULL;
-    } else {
-        *clKernel = idx->second;
-    }
-
-    delete[] kernelName;
+  // is kernel already compiled?
+  kernel_map_key key;
+  key.kernelSource = kernelSource;
+  key.context = clContext;
+  key.device = clDevice;
+  kernel_map_t::iterator idx = kernel_map->find(key);
+  if (idx == kernel_map->end()) {
+    *clKernel = NULL;
+  } else {
+    *clKernel = idx->second;
+    return;
   }
 
-  if (!*clKernel) {
+  if (true /*!*clKernel*/) { // since kernel wasn't found in map
     // kernel has not been built, so build it (from binary, preferably)
     cl_program clProgram;
     cl_int clBinaryStatus;
@@ -241,24 +270,20 @@ void makeGemmKernel(
 	err = clReleaseProgram(clProgram);
 	CL_CHECK(err)
 
-    char *kernelName = getKernelName(*clKernel);
-
 #ifdef AUTOGEMM_PRINT_DEBUG
-    printf("makeGemmKernel: \"%s\" now built; returning.\n", kernelName);
+    printf("makeGemmKernel now built; returning.\n");
 #endif
 
-    std::string key = prefix + "_" + kernelName;
-    kernel_map[key] = *clKernel;
-    delete[] kernelName;
+    //put kernel in map
+    (*kernel_map)[key] = *clKernel;
   }
-
   return;
 }
 
 /******************************************************************************
  * Enqueue Gemm Kernel
  *****************************************************************************/
- void enqueueGemmKernel(
+ cl_int enqueueGemmKernel(
    cl_command_queue clQueue,
    cl_kernel clKernel,
    void **kernelArgs,
@@ -271,14 +296,20 @@ void makeGemmKernel(
    cl_event *clEvent)
  {
    for (unsigned int i = 0; i < numKernelArgs; i++) {
-     CL_CHECK( clSetKernelArg( clKernel, i, kernelArgSizes[i], kernelArgs[i]) )
+	   cl_int err = clSetKernelArg(clKernel, i, kernelArgSizes[i], kernelArgs[i]);
+	   if (err != CL_SUCCESS)
+		   return err;
    }
    /*printf("global={%llu, %llu} local={%llu, %llu}\n",
      globalWorkSize[0], globalWorkSize[1],
      localWorkSize[0], localWorkSize[1] );*/
-   CL_CHECK( clEnqueueNDRangeKernel( clQueue, clKernel,
-      2, NULL, globalWorkSize, localWorkSize,
-      numEventsInWaitList, eventWaitList, clEvent ) )
+   cl_uint err = clEnqueueNDRangeKernel(clQueue, clKernel,
+	   2, NULL, globalWorkSize, localWorkSize,
+	   numEventsInWaitList, eventWaitList, clEvent);
+   if (err != CL_SUCCESS)
+	   return err;
+
+   return CL_SUCCESS;
  }
 
 
@@ -286,11 +317,11 @@ void makeGemmKernel(
  * get precision string
  *****************************************************************************/
 template<typename Precision>
-char * getPrecision();
-template<> char * getPrecision<float>() { return "s"; }
-template<> char * getPrecision<double>() { return "d"; }
-template<> char * getPrecision<FloatComplex>()  { return "c"; }
-template<> char * getPrecision<DoubleComplex>() { return "z"; }
+const char * getPrecision();
+template<> const char * getPrecision<float>() { return "s"; }
+template<> const char * getPrecision<double>() { return "d"; }
+template<> const char * getPrecision<FloatComplex>()  { return "c"; }
+template<> const char * getPrecision<DoubleComplex>() { return "z"; }
 
 
 /******************************************************************************
@@ -325,6 +356,8 @@ clblasGemm(
     const cl_event *eventWaitList,
     cl_event *events)
 {
+
+
   // cast types to opencl types
   cl_mem A = iA;
   cl_mem B = iB;
@@ -389,10 +422,13 @@ clblasGemm(
   cl_int err;
   cl_device_id clDevice;
   err = clGetCommandQueueInfo( commandQueues[0], CL_QUEUE_DEVICE, sizeof(clDevice), &clDevice, NULL);
-  CL_CHECK(err)
+  //CL_CHECK(err)
+  returnIfErr(err);
+
   cl_uint clDeviceNumCUs;
   err = clGetDeviceInfo( clDevice, CL_DEVICE_MAX_COMPUTE_UNITS, sizeof(clDeviceNumCUs), &clDeviceNumCUs, NULL);
-  CL_CHECK(err)
+  //CL_CHECK(err)
+  returnIfErr(err);
   unsigned int deviceIdealNumThreads = (8 /*waves per CU*/)*(64 /*threads per wave*/)*clDeviceNumCUs;
   float optimalNumElementsPerThread = ((float)M*N) / deviceIdealNumThreads;
   //optimalNumElementsPerThread = 32;
@@ -425,10 +461,10 @@ clblasGemm(
   size_t *colKernelBinarySize    = 0;
   size_t *cornerKernelBinarySize = 0;
   const char *binaryBuildOptions = NULL;
-  cl_kernel  *tileClKernel       = NULL;
-  cl_kernel  *rowClKernel        = NULL;
-  cl_kernel  *colClKernel        = NULL;
-  cl_kernel  *cornerClKernel     = NULL;
+  cl_kernel  *tileClKernelDummy       = NULL; // no longer used; broke thread safety
+  cl_kernel  *rowClKernelDummy        = NULL; // no longer used; broke thread safety
+  cl_kernel  *colClKernelDummy        = NULL; // no longer used; broke thread safety
+  cl_kernel  *cornerClKernelDummy     = NULL; // no longer used; broke thread safety
   unsigned int workGroupNumRows;
   unsigned int workGroupNumCols;
   unsigned int microTileNumRows;
@@ -453,10 +489,10 @@ clblasGemm(
     &colKernelBinarySize,
     &cornerKernelBinarySize,
     &binaryBuildOptions,
-    &tileClKernel,
-    &rowClKernel,
-    &colClKernel,
-    &cornerClKernel,
+    &tileClKernelDummy,
+    &rowClKernelDummy,
+    &colClKernelDummy,
+    &cornerClKernelDummy,
     &workGroupNumRows,
     &workGroupNumCols,
     &microTileNumRows,
@@ -464,7 +500,7 @@ clblasGemm(
     &unroll);
   // make sure gemmSelectKernel found a valid kernel
   if (!tileKernelSource) {
-    printf("ERROR: gemmSelectKernel() couldn't find kernel(s) for { order=%s, transA=%s, transB=%s, M=%llu, N=%llu, K=%llu, beta=%u, onept=%f }\n",
+    printf("ERROR: gemmSelectKernel() couldn't find kernel(s) for { order=%s, transA=%s, transB=%s, M=%u, N=%u, K=%u, beta=%u, onept=%f }\n",
       order==clblasColumnMajor ? "ColMajor" : "RowMajor",
       transA==clblasNoTrans ? "N" : transA==clblasTrans ? "T" : "C",
       transB==clblasNoTrans ? "N" : transB==clblasTrans ? "T" : "C",
@@ -494,10 +530,10 @@ clblasGemm(
           &colKernelBinarySize,
           &cornerKernelBinarySize,
           &binaryBuildOptions,
-          &tileClKernel,
-          &rowClKernel,
-          &colClKernel,
-          &cornerClKernel,
+          &tileClKernelDummy,
+          &rowClKernelDummy,
+          &colClKernelDummy,
+          &cornerClKernelDummy,
           &workGroupNumRows,
           &workGroupNumCols,
           &microTileNumRows,
@@ -530,10 +566,15 @@ clblasGemm(
 /******************************************************************************
  * Build kernels
  *****************************************************************************/
-  if (needTileKernel)   makeGemmKernel(  tileClKernel, commandQueues[0],   tileKernelSource, sourceBuildOptions,   &tileKernelBinary,   tileKernelBinarySize, binaryBuildOptions);
-  if (needRowKernel)    makeGemmKernel(   rowClKernel, commandQueues[0],    rowKernelSource, sourceBuildOptions,    &rowKernelBinary,    rowKernelBinarySize, binaryBuildOptions);
-  if (needColKernel)    makeGemmKernel(   colClKernel, commandQueues[0],    colKernelSource, sourceBuildOptions,    &colKernelBinary,    colKernelBinarySize, binaryBuildOptions);
-  if (needCornerKernel) makeGemmKernel(cornerClKernel, commandQueues[0], cornerKernelSource, sourceBuildOptions, &cornerKernelBinary, cornerKernelBinarySize, binaryBuildOptions);
+
+  cl_kernel  tileClKernel       = NULL;
+  cl_kernel  rowClKernel        = NULL;
+  cl_kernel  colClKernel        = NULL;
+  cl_kernel  cornerClKernel     = NULL;
+  if (needTileKernel)   makeGemmKernel(  &tileClKernel, commandQueues[0],   tileKernelSource, sourceBuildOptions,   &tileKernelBinary,   tileKernelBinarySize, binaryBuildOptions);
+  if (needRowKernel)    makeGemmKernel(   &rowClKernel, commandQueues[0],    rowKernelSource, sourceBuildOptions,    &rowKernelBinary,    rowKernelBinarySize, binaryBuildOptions);
+  if (needColKernel)    makeGemmKernel(   &colClKernel, commandQueues[0],    colKernelSource, sourceBuildOptions,    &colKernelBinary,    colKernelBinarySize, binaryBuildOptions);
+  if (needCornerKernel) makeGemmKernel(&cornerClKernel, commandQueues[0], cornerKernelSource, sourceBuildOptions, &cornerKernelBinary, cornerKernelBinarySize, binaryBuildOptions);
   const size_t localWorkSize[2] = { workGroupNumRows, workGroupNumCols };
   unsigned int numKernelsEnqueued = 0;
 
@@ -562,11 +603,12 @@ clblasGemm(
   if (needTileKernel) {
     //printf("enqueueing tile kernel\n");
     size_t globalWorkSize[2] = {(M/macroTileNumRows)*workGroupNumRows, (N/macroTileNumCols)*workGroupNumCols };
-    enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], *tileClKernel,
+    err = enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], tileClKernel,
       gemmKernelArgs, gemmKernelArgSizes, numGemmKernelArgs,
       globalWorkSize, localWorkSize,
       numEventsInWaitList, eventWaitList,
       &events[numKernelsEnqueued%numCommandQueues] );
+	returnIfErr(err);
     numKernelsEnqueued++;
   }
 
@@ -576,11 +618,12 @@ clblasGemm(
   if (needRowKernel) {
     //printf("enqueueing row kernel\n");
     size_t globalWorkSize[2] = {1*workGroupNumRows, (N/macroTileNumCols)*workGroupNumCols };
-    enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], *rowClKernel,
+    err = enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], rowClKernel,
       gemmKernelArgs, gemmKernelArgSizes, numGemmKernelArgs,
       globalWorkSize, localWorkSize,
       numEventsInWaitList, eventWaitList,
       &events[numKernelsEnqueued%numCommandQueues] );
+	returnIfErr(err);
     numKernelsEnqueued++;
   }
 
@@ -590,11 +633,12 @@ clblasGemm(
   if (needColKernel) {
     //printf("enqueueing col kernel\n");
     size_t globalWorkSize[2] = { (M/macroTileNumRows)*workGroupNumRows, 1*workGroupNumCols };
-    enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], *colClKernel,
+    err = enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], colClKernel,
       gemmKernelArgs, gemmKernelArgSizes, numGemmKernelArgs,
       globalWorkSize, localWorkSize,
       numEventsInWaitList, eventWaitList,
       &events[numKernelsEnqueued%numCommandQueues] );
+	returnIfErr(err);
     numKernelsEnqueued++;
   }
 
@@ -604,11 +648,12 @@ clblasGemm(
   if (needCornerKernel) {
     //printf("enqueueing corner kernel\n");
     size_t globalWorkSize[2] = { 1*workGroupNumRows, 1*workGroupNumCols };
-    enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], *cornerClKernel,
+    err = enqueueGemmKernel( commandQueues[numKernelsEnqueued%numCommandQueues], cornerClKernel,
       gemmKernelArgs, gemmKernelArgSizes, numGemmKernelArgs,
       globalWorkSize, localWorkSize,
       numEventsInWaitList, eventWaitList,
       &events[numKernelsEnqueued%numCommandQueues] );
+	returnIfErr(err);
     numKernelsEnqueued++;
   }
 
@@ -637,6 +682,29 @@ clblasSgemm(
     const cl_event *eventWaitList,
     cl_event *events)
 {
+  // check if memory objects are valid
+  clblasStatus clblasErr = clblasSuccess;
+  clblasErr = checkMemObjects(A, B, C, true, A_MAT_ERRSET, B_MAT_ERRSET, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+  	  return clblasErr;
+
+  if (K != 0)
+  {
+  	//check matrix A
+  	clblasErr = checkMatrixSizes(TYPE_FLOAT, order, transA, M, K, A, offA, lda, A_MAT_ERRSET);
+  	if (clblasErr != clblasSuccess)
+  		return clblasErr;
+
+  	//check matrix B
+	clblasErr = checkMatrixSizes(TYPE_FLOAT, order, transB, K, N, B, offB, ldb, B_MAT_ERRSET);
+	if (clblasErr != clblasSuccess)
+		return clblasErr;
+  }
+  //check matrix C
+  clblasErr = checkMatrixSizes(TYPE_FLOAT, order, clblasNoTrans, M, N, C, offC, ldc, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+      return clblasErr;
+
   return clblasGemm(
        order,
        transA,
@@ -674,6 +742,29 @@ clblasDgemm( clblasOrder order,
              const cl_event *eventWaitList,
              cl_event *events)
 {
+  // check if memory objects are valid
+  clblasStatus clblasErr = clblasSuccess;
+  clblasErr = checkMemObjects(A, B, C, true, A_MAT_ERRSET, B_MAT_ERRSET, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+  	  return clblasErr;
+
+  if (K != 0)
+  {
+  	//check matrix A
+  	clblasErr = checkMatrixSizes(TYPE_DOUBLE, order, transA, M, K, A, offA, lda, A_MAT_ERRSET);
+  	if (clblasErr != clblasSuccess)
+  		return clblasErr;
+
+  	//check matrix B
+  	clblasErr = checkMatrixSizes(TYPE_DOUBLE, order, transB, K, N, B, offB, ldb, B_MAT_ERRSET);
+  	if (clblasErr != clblasSuccess)
+  		return clblasErr;
+  }
+  //check matrix C
+  clblasErr = checkMatrixSizes(TYPE_DOUBLE, order, clblasNoTrans, M, N, C, offC, ldc, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+      return clblasErr;
+
    return clblasGemm(
        order,
        transA,
@@ -712,6 +803,29 @@ clblasCgemm(
     const cl_event *eventWaitList,
     cl_event *events)
 {
+  // check if memory objects are valid
+  clblasStatus clblasErr = clblasSuccess;
+  clblasErr = checkMemObjects(A, B, C, true, A_MAT_ERRSET, B_MAT_ERRSET, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+  	return clblasErr;
+
+  if (K != 0)
+  {
+  	//check matrix A
+  	clblasErr = checkMatrixSizes(TYPE_COMPLEX_FLOAT, order, transA, M, K, A, offA, lda, A_MAT_ERRSET);
+  	if (clblasErr != clblasSuccess)
+  		return clblasErr;
+
+  	//check matrix B
+  	clblasErr = checkMatrixSizes(TYPE_COMPLEX_FLOAT, order, transB, K, N, B, offB, ldb, B_MAT_ERRSET);
+  	if (clblasErr != clblasSuccess)
+  		return clblasErr;
+  }
+  //check matrix C
+  clblasErr = checkMatrixSizes(TYPE_COMPLEX_FLOAT, order, clblasNoTrans, M, N, C, offC, ldc, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+  	  return clblasErr;
+
    return clblasGemm(
        order,
        transA,
@@ -750,6 +864,29 @@ clblasZgemm(
     const cl_event *eventWaitList,
     cl_event *events)
 {
+  // check if memory objects are valid
+  clblasStatus clblasErr = clblasSuccess;
+  clblasErr = checkMemObjects(A, B, C, true, A_MAT_ERRSET, B_MAT_ERRSET, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+  	  return clblasErr;
+
+  if (K != 0)
+  {
+  	//check matrix A
+  	clblasErr = checkMatrixSizes(TYPE_COMPLEX_DOUBLE, order, transA, M, K, A, offA, lda, A_MAT_ERRSET);
+  	if (clblasErr != clblasSuccess)
+  		return clblasErr;
+
+  	//check matrix B
+  	clblasErr = checkMatrixSizes(TYPE_COMPLEX_DOUBLE, order, transB, K, N, B, offB, ldb, B_MAT_ERRSET);
+  	if (clblasErr != clblasSuccess)
+  		return clblasErr;
+  }
+  //check matrix C
+  clblasErr = checkMatrixSizes(TYPE_COMPLEX_DOUBLE, order, clblasNoTrans, M, N, C, offC, ldc, C_MAT_ERRSET);
+  if (clblasErr != clblasSuccess)
+  	  return clblasErr;
+
    return clblasGemm(
        order,
        transA,
