@@ -103,10 +103,10 @@ doRotm(
 		kargs->N = N;
 		kargs->A = X;
 		kargs->offBX = offx;
-		kargs->ldb.vector = incx;	// Will be using this as incx
+		kargs->ldb.Vector = incx;	// Will be using this as incx
 		kargs->B = Y;
 		kargs->offCY = offy;
-		kargs->ldc.vector = incy;	// Will be using this as incy
+		kargs->ldc.Vector = incy;	// Will be using this as incy
 		kargs->D = param;
 		kargs->offd = offParam;
 		kargs->pigFuncID = CLBLAS_ROTM;
