@@ -77,8 +77,7 @@ gemmCorrectnessTest(TestParams *params)
                  (typeid(T) == typeid(DoubleComplex)));
 
     if (canCaseBeSkipped(params, isComplex)) {
-        std::cerr << ">> Test is skipped because it has no importance for this "
-                     "level of coverage" << std::endl;
+        std::cerr << ">> Test is skipped" << std::endl;
         SUCCEED();
         return;
     }
@@ -104,14 +103,11 @@ gemmCorrectnessTest(TestParams *params)
         beta = convertMultiplier<T>(params->beta);
     }
 
-    //::std::cerr << "Generating input data... ";
     randomGemmMatrices<T>(params->order, params->transA, params->transB,
         params->M, params->N, params->K, useAlpha, &alpha, A, params->lda,
         B, params->ldb, useBeta, &beta, blasC, params->ldc);
     memcpy(clblasC, blasC, params->rowsC * params->columnsC * sizeof(*blasC));
-    //::std::cerr << "Done" << ::std::endl;
 
-    //::std::cerr << "Calling reference xGEMM routine... ";
     if (params->order == clblasColumnMajor) {
         ::clMath::blas::gemm(clblasColumnMajor, params->transA, params->transB,
                           params->M, params->N, params->K, alpha, A,
@@ -139,7 +135,6 @@ gemmCorrectnessTest(TestParams *params)
         delete[] reorderedB;
         delete[] reorderedA;
     }
-    //::std::cerr << "Done" << ::std::endl;
 
     bufA = base->createEnqueueBuffer(A, params->rowsA * params->columnsA *
                                         sizeof(*A), params->offA * sizeof(*A),
@@ -167,7 +162,6 @@ gemmCorrectnessTest(TestParams *params)
         return;
     }
 
-    //::std::cerr << "Calling clblas xGEMM routine... ";
     err = (cl_int)::clMath::clblas::gemm(params->order, params->transA,
         params->transB, params->M, params->N, params->K, alpha, bufA,
         params->offA, params->lda, bufB, params->offBX, params->ldb, beta,
@@ -188,7 +182,6 @@ gemmCorrectnessTest(TestParams *params)
         delete[] events;
         ASSERT_EQ(CL_SUCCESS, err) << "waitForSuccessfulFinish()";
     }
-    //::std::cerr << "Done" << ::std::endl;
 
     clEnqueueReadBuffer(base->commandQueues()[0], bufC, CL_TRUE,
                         params->offCY * sizeof(*clblasC),
@@ -198,6 +191,16 @@ gemmCorrectnessTest(TestParams *params)
     releaseMemObjects(bufA, bufB, bufC);
     compareMatrices<T>(params->order, params->M, params->N, blasC, clblasC,
                        params->ldc);
+
+    if (::testing::Test::HasFailure( ) )
+    {
+        printTestParams(params->order, params->transA, params->transB, params->M, params->N, params->K, base->useAlpha(),
+            base->alpha(), params->offA, params->lda, params->offBX, params->ldb, base->useBeta(),
+            base->beta(), params->offCY, params->ldc);
+        ::std::cerr << "             seed = " << params->seed << ", "
+            << "queues = " << params->numCommandQueues << ", ";
+    }
+
     deleteBuffers<T>(A, B, blasC, clblasC);
     delete[] events;
 }
